Index: trunk/MagicSoft/Mars/Changelog
===================================================================
--- trunk/MagicSoft/Mars/Changelog	(revision 4123)
+++ trunk/MagicSoft/Mars/Changelog	(revision 4124)
@@ -29,4 +29,8 @@
      - added a debug switch with which you can print out Object
        Allocation (like suggested by TBretz).
+
+   * mcalib/MCalibrationRelTimeCalc.cc
+     - replaced the relative limit for acceptance of the time resolution 
+       by an absolute limit
 
 
Index: trunk/MagicSoft/Mars/mcalib/MCalibrationRelTimeCalc.h
===================================================================
--- trunk/MagicSoft/Mars/mcalib/MCalibrationRelTimeCalc.h	(revision 4123)
+++ trunk/MagicSoft/Mars/mcalib/MCalibrationRelTimeCalc.h	(revision 4124)
@@ -32,9 +32,9 @@
 private:
 
-  static const Float_t fgRelTimeRelErrLimit;      //! Default for fRelTimeRelErrLimit      (now set to: 6.)
+  static const Float_t fgRelTimeResolutionLimit; //! Default for fRelTimeResolutionLimit (now set to: 1.)
  
   // Variables
-  Float_t fRelTimeRelErrLimit;                  // Limit acceptance rel. error mean (in abs. numbers)
-  Byte_t  fFlags;                              // Bit-field for the flags
+  Float_t fRelTimeResolutionLimit;              // Limit acceptance rel. time resolution (in FADC slices)
+  Byte_t  fFlags;                               // Bit-field for the flags
   
   // Pointers
@@ -65,5 +65,5 @@
   void Clear(const Option_t *o="");
   
-  void SetRelTimeRelErrLimit ( const Float_t f=fgRelTimeRelErrLimit      ) { fRelTimeRelErrLimit = f;   }
+  void SetRelTimeResolutionLimit ( const Float_t f=fgRelTimeResolutionLimit    ) { fRelTimeResolutionLimit = f;   }
 
   void SkipHiLoGainCalibration ( const Bool_t b=kTRUE )
